@@ -97,10 +97,15 @@ class DatasetCore:
         Returns:
             dask.dataframe.DataFrame: use .compute to get final result.
         """
-        data = self.daskdataframe.groupby("original_id").agg(agg)
-        data["N"] = self.daskdataframe.groupby("original_id").size()
-        data["original_id"] = data.index
-        data = data.reset_index(drop=True)
+        if self.has_original_id:
+            data = self.daskdataframe.groupby("original_id").agg(agg)
+            data["N"] = self.daskdataframe.groupby("original_id").size()
+            data["original_id"] = data.index
+            data = data.reset_index(drop=True)
+        else:
+            data = self.daskdataframe
+            data["dummy"] = data.index
+            data = data.groupby("dummy").agg(agg)
         return data
 
     def has_pointclouds(self) -> bool:
